@@ -130,8 +130,7 @@ class ApiGatewayToKinesisStreams(
     jsii_type="@aws-solutions-constructs/aws-apigateway-kinesisstreams.ApiGatewayToKinesisStreams",
 ):
     """
-    summary:
-    :summary:: The ApiGatewayToKinesisStreams class.
+    :summary: The ApiGatewayToKinesisStreams class.
     """
 
     def __init__(
@@ -158,12 +157,9 @@ class ApiGatewayToKinesisStreams(
         :param put_records_request_model: API Gateway request model for the PutRecords action. If not provided, a default one will be created. Default: - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecords proxy payload data","type":"object","required":["records"], "properties":{"records":{"type":"array","items":{"type":"object", "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
         :param put_records_request_template: API Gateway request template for the PutRecords action. If not provided, a default one will be used. Default: - { "StreamName": "${this.kinesisStream.streamName}", "Records": [ #foreach($elem in $input.path('$.records')) { "Data": "$util.base64Encode($elem.data)", "PartitionKey": "$elem.partitionKey"}#if($foreach.hasNext),#end #end ] }
 
-        access:
-        :access:: public
-        since:
-        :since:: 1.62.0
-        summary:
-        :summary:: Constructs a new instance of the ApiGatewayToKinesisStreams class.
+        :access: public
+        :since: 1.62.0
+        :summary: Constructs a new instance of the ApiGatewayToKinesisStreams class.
         """
         props = ApiGatewayToKinesisStreamsProps(
             api_gateway_props=api_gateway_props,
@@ -237,8 +233,7 @@ class ApiGatewayToKinesisStreamsProps:
         :param put_records_request_model: API Gateway request model for the PutRecords action. If not provided, a default one will be created. Default: - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecords proxy payload data","type":"object","required":["records"], "properties":{"records":{"type":"array","items":{"type":"object", "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
         :param put_records_request_template: API Gateway request template for the PutRecords action. If not provided, a default one will be used. Default: - { "StreamName": "${this.kinesisStream.streamName}", "Records": [ #foreach($elem in $input.path('$.records')) { "Data": "$util.base64Encode($elem.data)", "PartitionKey": "$elem.partitionKey"}#if($foreach.hasNext),#end #end ] }
 
-        summary:
-        :summary:: The properties for the ApiGatewayToKinesisStreamsProps class.
+        :summary: The properties for the ApiGatewayToKinesisStreamsProps class.
         """
         if isinstance(api_gateway_props, dict):
             api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
@@ -268,7 +263,6 @@ class ApiGatewayToKinesisStreamsProps:
     def api_gateway_props(self) -> typing.Optional[aws_cdk.aws_apigateway.RestApiProps]:
         """Optional user-provided props to override the default props for the API Gateway.
 
-        default
         :default: - Default properties are used.
         """
         result = self._values.get("api_gateway_props")
@@ -278,7 +272,6 @@ class ApiGatewayToKinesisStreamsProps:
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
         """Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_stream_obj")
@@ -288,7 +281,6 @@ class ApiGatewayToKinesisStreamsProps:
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
         """Optional user-provided props to override the default props for the Kinesis Data Stream.
 
-        default
         :default: - Default properties are used.
         """
         result = self._values.get("kinesis_stream_props")
@@ -302,11 +294,10 @@ class ApiGatewayToKinesisStreamsProps:
 
         If not provided, a default one will be created.
 
-        default
         :default:
 
         - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecord proxy single-record payload","type":"object",
-          "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}
+        "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}
         """
         result = self._values.get("put_record_request_model")
         return result
@@ -317,11 +308,10 @@ class ApiGatewayToKinesisStreamsProps:
 
         If not provided, a default one will be used.
 
-        default
         :default:
 
         - { "StreamName": "${this.kinesisStream.streamName}", "Data": "$util.base64Encode($input.json('$.data'))",
-          "PartitionKey": "$input.path('$.partitionKey')" }
+        "PartitionKey": "$input.path('$.partitionKey')" }
         """
         result = self._values.get("put_record_request_template")
         return result
@@ -334,12 +324,11 @@ class ApiGatewayToKinesisStreamsProps:
 
         If not provided, a default one will be created.
 
-        default
         :default:
 
         - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecords proxy payload data","type":"object","required":["records"],
-          "properties":{"records":{"type":"array","items":{"type":"object",
-          "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
+        "properties":{"records":{"type":"array","items":{"type":"object",
+        "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
         """
         result = self._values.get("put_records_request_model")
         return result
@@ -350,11 +339,10 @@ class ApiGatewayToKinesisStreamsProps:
 
         If not provided, a default one will be used.
 
-        default
         :default:
 
         - { "StreamName": "${this.kinesisStream.streamName}", "Records": [ #foreach($elem in $input.path('$.records'))
-          { "Data": "$util.base64Encode($elem.data)", "PartitionKey": "$elem.partitionKey"}#if($foreach.hasNext),#end #end ] }
+        { "Data": "$util.base64Encode($elem.data)", "PartitionKey": "$elem.partitionKey"}#if($foreach.hasNext),#end #end ] }
         """
         result = self._values.get("put_records_request_template")
         return result
